#!/usr/bin/python

"""
Writes SQL from grinder output logs. Spits it to stdout so can be
piped to command line SQL clients for any ANSI 92 compliant DB

Table definitions:

CREATE TABLE DATA (
	ID VARCHAR(255) NOT NULL,
	THREAD INTEGER NOT NULL,
	RUN INTEGER NOT NULL,
	TEST INTEGER NOT NULL,
	MILLISECONDS_SINCE_START INTEGER NOT NULL,
	TEST_TIME INTEGER NOT NULL,
	ERRORS INTEGER NOT NULL,
	HTTP_RESPONSE_CODE INTEGER NOT NULL,
	HTTP_RESPONSE_LENGTH INTEGER NOT NULL,
	HTTP_RESPONSE_ERRORS INTEGER NOT NULL,
	TIME_TO_RESOLVE_HOST INTEGER NOT NULL,
	TIME_TO_ESTABLISH_CONNECTION INTEGER NOT NULL,
	TIME_TO_FIRST_BYTE INTEGER NOT NULL);

CREATE INDEX DATA_ID ON DATA (ID);
CREATE INDEX DATA_MILLISECONDS_SINCE_START ON DATA (MILLISECONDS_SINCE_START);
CREATE INDEX DATA_TEST ON DATA (TEST);

CREATE TABLE DESCRIPTIONS (
	ID VARCHAR(255) NOT NULL,
	TEST REAL NOT NULL,
	DESCRIPTION VARCHAR(255) NOT NULL);

CREATE INDEX DATA_ID ON DATA (ID);

Author: Robin Rawson-Tetley
Date:   9th March, 2006

This script has no dependencies on any python libraries that exist outside
Jython so can be run with both.
"""

import sys

if len(sys.argv) < 4:
	print "Usage: grinder2sql <identifier> <console_data_file>  <csvfile> [ <csvfile> ... ]"
	sys.exit(1)

identifier = sys.argv[1]
console = sys.argv[2]

print "BEGIN TRANSACTION;\n\n"

# Parse the console file
f = open(console)
clines = f.readlines()
f.close()
for l in clines:
	if l.find("Description") == -1:
	 	b = l.split("\t")
		# Grab the test number and description
		ts = b[0]
		testnumber = ts[ts.find(" ") + 1:len(ts)]
		description = b[1]
		
		# Write an INSERT query for this entry
		s = "INSERT INTO DESCRIPTIONS VALUES ('%s', %s, '%s');\n" % (identifier, testnumber, description) 
		print s

# Loop through each CSV file given
for fileidx in range(3, len(sys.argv)):
	f = open(sys.argv[fileidx], 'r')

	# Read lines and write the SQL for the rows
	while(1):
		s = f.readline()
		if not s.startswith("Thread"):
			# Drop out on EOF
			if s == "": break
			vals = s.strip().split(",")
			s = "'" + identifier + "'"
			for v in vals:
				s += ", " + v
			# Construct the insert query
			print "INSERT INTO DATA VALUES (" + s + ");\n"

	# Clean up
	f.close()

print "\n\nCOMMIT;"

